# Todo

## To Do

[ ] Get rid of the config file (might have found a solution!)
[ ] Fix downgrading mods

## In Progress

[ ] Add comments to the code
[ ] Search mods from Modrinth

## Completed

[x] Add logging - 2026-03-11
[x] Improve code structure - 2026-03-11
[x] List installed packages - 2026-03-10
[x] Improve command line arguments - 2026-03-07
[x] Add help message for command line arguments that do not already have them - 2026-03-07
